@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "jobtrackersearchwidgettest.h"
@@ -27,18 +16,16 @@
 JobTrackerSearchWidgetTest::JobTrackerSearchWidgetTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 JobTrackerSearchWidgetTest::~JobTrackerSearchWidgetTest()
 {
-
 }
 
 void JobTrackerSearchWidgetTest::shouldHaveDefaultValue()
 {
     JobTrackerSearchWidget w;
-    QHBoxLayout *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
+    auto *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
     int top = -1;
     int bottom = -1;
@@ -50,18 +37,17 @@ void JobTrackerSearchWidgetTest::shouldHaveDefaultValue()
     QCOMPARE(left, 0);
     QCOMPARE(right, 0);
 
-    QLineEdit *mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
+    auto *mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
     QVERIFY(mSearchLineEdit);
     QVERIFY(mSearchLineEdit->isClearButtonEnabled());
     QVERIFY(mSearchLineEdit->text().isEmpty());
 
-    QComboBox *mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
+    auto *mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
     QVERIFY(mSelectColumn);
     QCOMPARE(mSelectColumn->count(), 8);
     QCOMPARE(mSelectColumn->currentIndex(), 0);
 
-
-    QCheckBox *mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
+    auto *mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
     QVERIFY(mSelectOnlyError);
     QVERIFY(!mSelectOnlyError->text().isEmpty());
     QCOMPARE(mSelectOnlyError->checkState(), Qt::Unchecked);
@@ -71,7 +57,7 @@ void JobTrackerSearchWidgetTest::shouldEmitSignal()
 {
     JobTrackerSearchWidget w;
     QSignalSpy searchWidgetSignal(&w, &JobTrackerSearchWidget::searchTextChanged);
-    QLineEdit *mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
+    auto *mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
     const QString foo = QStringLiteral("foo");
     mSearchLineEdit->setText(foo);
     QCOMPARE(searchWidgetSignal.count(), 1);
@@ -85,7 +71,7 @@ void JobTrackerSearchWidgetTest::shouldEmitColumnChanged()
 {
     JobTrackerSearchWidget w;
     QSignalSpy columnChangedSignal(&w, &JobTrackerSearchWidget::columnChanged);
-    QComboBox *mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
+    auto *mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
     mSelectColumn->setCurrentIndex(2);
     QCOMPARE(columnChangedSignal.count(), 1);
 }
@@ -94,7 +80,7 @@ void JobTrackerSearchWidgetTest::shouldEmitSelectOnlyErrorChanged()
 {
     JobTrackerSearchWidget w;
     QSignalSpy selectOnlyErrorChangedSignal(&w, &JobTrackerSearchWidget::selectOnlyErrorChanged);
-    QCheckBox *mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
+    auto *mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
     mSelectOnlyError->setChecked(true);
     QCOMPARE(selectOnlyErrorChangedSignal.count(), 1);
 }
