@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2018 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2018 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "loggingmodel.h"
@@ -46,12 +33,10 @@ QString LoggingModel::cacheString(const QString &str, QSet<QString> &cache, QSta
         cache.insert(str);
         return str;
     }
-    return (*it);
+    return *it;
 }
 
-void LoggingModel::addMessage(qint64 timestamp, const QString &app, qint64 pid, QtMsgType type,
-                              const QString &category, const QString &file, 
-                              const QString &function, int line, const QString &message)
+void LoggingModel::addMessage(qint64 timestamp, const QString &app, qint64 pid, QtMsgType type, const QString &category, const QString &file, const QString &function, int line, const QString &message)
 {
     beginInsertRows({}, mMessages.count(), mMessages.count());
     mMessages.push_back({ timestamp, cacheString(app, mAppCache, mAppFilterModel), pid,
@@ -66,12 +51,12 @@ void LoggingModel::setAppFilterModel(QStandardItemModel *appFilterModel)
     mAppFilterModel = appFilterModel;
 }
 
-void LoggingModel::setCategoryFilterModel(QStandardItemModel* categoryFilterModel)
+void LoggingModel::setCategoryFilterModel(QStandardItemModel *categoryFilterModel)
 {
     mCategoryFilterModel = categoryFilterModel;
 }
 
-int LoggingModel::rowCount(const QModelIndex& parent) const
+int LoggingModel::rowCount(const QModelIndex &parent) const
 {
     return parent.isValid() ? 0 : mMessages.count();
 }
@@ -120,7 +105,6 @@ QVariant LoggingModel::headerData(int section, Qt::Orientation orientation, int
     return {};
 }
 
-
 QVariant LoggingModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid() || index.row() >= mMessages.count() || index.column() >= _ColumnCount) {
@@ -187,7 +171,3 @@ QVariant LoggingModel::data(const QModelIndex &index, int role) const
 
     return {};
 }
-
-
-
-
