@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -37,15 +25,15 @@
 
 Q_DECLARE_METATYPE(Akonadi::NotificationSubscriber)
 
-MonitorsWidget::MonitorsWidget(QWidget *parent):
-    QWidget(parent)
+MonitorsWidget::MonitorsWidget(QWidget *parent)
+    : QWidget(parent)
 {
     mModel = new MonitorsModel(this);
 
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
 
     mTreeView = new QTreeView(this);
-    QSortFilterProxyModel *mProxyModel = new QSortFilterProxyModel(this);
+    auto *mProxyModel = new QSortFilterProxyModel(this);
     mProxyModel->setDynamicSortFilter(true);
     mProxyModel->sort(0);
     mProxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
@@ -109,14 +97,12 @@ QString toString(const QSet<Akonadi::Monitor::Type> &set)
     return rv.join(QLatin1String(", "));
 }
 
-
-void MonitorsWidget::populateCollectionFetchScope(QStandardItem *parent,
-                                                  const Akonadi::CollectionFetchScope &cfs)
+void MonitorsWidget::populateCollectionFetchScope(QStandardItem *parent, const Akonadi::CollectionFetchScope &cfs)
 {
     appendRow(parent, QStringLiteral("List Filter"), toString(cfs.listFilter()));
     appendRow(parent, QStringLiteral("Include Statistics"), toString(cfs.includeStatistics()));
     appendRow(parent, QStringLiteral("Resource"), cfs.resource());
-    appendRow(parent, QStringLiteral("Content MimeTypes"), toString(static_cast<QList<QString>>(cfs.contentMimeTypes())));
+    appendRow(parent, QStringLiteral("Content MimeTypes"), toString(static_cast<QList<QString> >(cfs.contentMimeTypes())));
     appendRow(parent, QStringLiteral("Ancestor Retrieval"), toString(cfs.ancestorRetrieval()));
 
     const auto ancestorFs = cfs.ancestorFetchScope();
@@ -131,17 +117,15 @@ void MonitorsWidget::populateCollectionFetchScope(QStandardItem *parent,
     appendRow(parent, QStringLiteral("Ignore Retrieval Error"), toString(cfs.ignoreRetrievalErrors()));
 }
 
-void MonitorsWidget::populateTagFetchScope(QStandardItem *parent,
-                                           const Akonadi::TagFetchScope& tfs)
+void MonitorsWidget::populateTagFetchScope(QStandardItem *parent, const Akonadi::TagFetchScope &tfs)
 {
     appendRow(parent, QStringLiteral("Attributes"), toString(tfs.attributes()));
     appendRow(parent, QStringLiteral("Fetch ID Only"), toString(tfs.fetchIdOnly()));
 }
 
-
-void MonitorsWidget::onSubscriberSelected(const QModelIndex& index)
+void MonitorsWidget::onSubscriberSelected(const QModelIndex &index)
 {
-    auto model = qobject_cast<QStandardItemModel*>(mSubscriberView->model());
+    auto model = qobject_cast<QStandardItemModel *>(mSubscriberView->model());
     const auto state = mSubscriberView->header()->saveState();
     model->clear();
     model->setHorizontalHeaderLabels({ QStringLiteral("Properties"), QStringLiteral("Values") });
@@ -191,4 +175,3 @@ void MonitorsWidget::onSubscriberSelected(const QModelIndex& index)
 
     mSubscriberView->expandAll();
 }
-
